@@ -7,11 +7,11 @@
 class FalconSphereTest : public FalconTestBase
 {
 public:
-	FalconSphereTest(boost::shared_ptr<libnifalcon::FalconDevice> d);
+	FalconSphereTest(std::shared_ptr<libnifalcon::FalconDevice> d);
 protected:
 	double m_stiffness;
     double m_radius;
-    boost::array<double, 3> m_oldpos;
+	std::array<double, 3> m_oldpos;
     bool m_plusButtonDown;
     bool m_minusButtonDown;
     bool m_centerButtonDown;
